--******************************************************************************************************************************
--* Licensed Materials - Property of IBM                                                                                       *
--* (c) Copyright IBM Corp. 2008, 2009 All Rights Reserved.                                                                    *
--*                                                                                                                            *
--*US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp*
--******************************************************************************************************************************


------------------------------------------------
-- DDL Statements for table CMSYSPROPS
------------------------------------------------
 

CREATE TABLE CMSYSPROPS  (
		  PROPNAME VARCHAR(50) NOT NULL , 
		  CI_PROPNAME VARCHAR(50) NOT NULL , 
		  PROPVALUE CLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMSYSPROPS

ALTER TABLE CMSYSPROPS 
	ADD CONSTRAINT PK_CMSYSPROPS PRIMARY KEY
		(CI_PROPNAME);


------------------------------------------------
-- DDL Statements for table CMCAPACITY
------------------------------------------------
 

CREATE TABLE CMCAPACITY  (
		  CMPATH VARCHAR(3220) NOT NULL , 
		  CAPACITY DOUBLE , 
		  USAGE SMALLINT NOT NULL )   
		 IN CTBS_4K ; 





------------------------------------------------
-- DDL Statements for table CMCRYPTOKEYS
------------------------------------------------
 

CREATE TABLE CMCRYPTOKEYS  (
		  CRYPTOKEY VARCHAR(255) NOT NULL , 
		  CI_CRYPTOKEY VARCHAR(255) NOT NULL , 
		  DATA BLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMCRYPTOKEYS

ALTER TABLE CMCRYPTOKEYS 
	ADD CONSTRAINT PK_CMCRYPTOKEYS PRIMARY KEY
		(CI_CRYPTOKEY);


------------------------------------------------
-- DDL Statements for table CMCAKEYS
------------------------------------------------
 

CREATE TABLE CMCAKEYS  (
		  CAKEY VARCHAR(255) NOT NULL , 
		  CI_CAKEY VARCHAR(255) NOT NULL , 
		  DATA BLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMCAKEYS

ALTER TABLE CMCAKEYS 
	ADD CONSTRAINT PK_CMCAKEYS PRIMARY KEY
		(CI_CAKEY);


------------------------------------------------
-- DDL Statements for table CMCAPROPS
------------------------------------------------
 

CREATE TABLE CMCAPROPS  (
		  PROPNAME VARCHAR(50) NOT NULL , 
		  PROPINTVALUE INTEGER NOT NULL , 
		  PROPVALUE CLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMCAPROPS

ALTER TABLE CMCAPROPS 
	ADD CONSTRAINT PK_CMCAPROPS PRIMARY KEY
		(PROPNAME);


------------------------------------------------
-- DDL Statements for table CMOBJECTS
------------------------------------------------
 

CREATE TABLE CMOBJECTS  (
		  CMID INTEGER NOT NULL , 
		  PCMID INTEGER NOT NULL , 
		  VERSION INTEGER NOT NULL WITH DEFAULT 1 , 
		  CREATED TIMESTAMP NOT NULL , 
		  MODIFIED TIMESTAMP NOT NULL , 
		  DISABLED SMALLINT , 
		  CLASSID SMALLINT NOT NULL , 
		  DISPSEQ INTEGER NOT NULL WITH DEFAULT 0 , 
		  OWNER INTEGER )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJECTS

ALTER TABLE CMOBJECTS 
	ADD CONSTRAINT PK_CMOBJECTS PRIMARY KEY
		(CMID);



-- DDL Statements for indexes on Table CMOBJECTS

CREATE INDEX IDX_CLASS ON CMOBJECTS 
		(CLASSID ASC)
		ALLOW REVERSE SCANS;

-- DDL Statements for indexes on Table CMOBJECTS

CREATE INDEX IDX_CLASS1 ON CMOBJECTS 
		(CMID ASC,
		 CLASSID ASC)
		ALLOW REVERSE SCANS;

-- DDL Statements for indexes on Table CMOBJECTS

CREATE INDEX IDX_CREATED ON CMOBJECTS 
		(CREATED ASC)
		ALLOW REVERSE SCANS;

-- DDL Statements for indexes on Table CMOBJECTS

CREATE INDEX IDX_PARENT ON CMOBJECTS 
		(PCMID ASC)
		ALLOW REVERSE SCANS;
-- DDL Statements for unique constraints on Table CMOBJECTS


ALTER TABLE CMOBJECTS 
	ADD CONSTRAINT PK_CMPARENT UNIQUE
		(PCMID,
		 CMID);

------------------------------------------------
-- DDL Statements for table CMOBJNAMES
------------------------------------------------
 

CREATE TABLE CMOBJNAMES  (
		  CMID INTEGER NOT NULL , 
		  LOCALEID SMALLINT NOT NULL , 
		  MAPDLOCALEID SMALLINT , 
		  ISDEFAULT DECIMAL(1,0) NOT NULL , 
		  NAME VARCHAR(255) NOT NULL )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJNAMES

ALTER TABLE CMOBJNAMES 
	ADD CONSTRAINT PK_CMOBJNAMES PRIMARY KEY
		(CMID,
		 LOCALEID);


------------------------------------------------
-- DDL Statements for table CMDATA
------------------------------------------------
 

CREATE TABLE CMDATA  (
		  CMID INTEGER NOT NULL , 
		  CONTENTTYPE VARCHAR(256) , 
		  DATASIZE INTEGER , 
		  DATACOMP DECIMAL(1,0) NOT NULL WITH DEFAULT 0 , 
		  DATAPROP BLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMDATA

ALTER TABLE CMDATA 
	ADD CONSTRAINT PK_CMDATA PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMSTOREIDS
------------------------------------------------
 

CREATE TABLE CMSTOREIDS  (
		  CMID INTEGER NOT NULL , 
		  STOREID CHAR(33) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMSTOREIDS

ALTER TABLE CMSTOREIDS 
	ADD CONSTRAINT PK_CMSTOREIDS PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS1
------------------------------------------------
 

CREATE TABLE CMOBJPROPS1  (
		  CMID INTEGER NOT NULL , 
		  BUSPHONE VARCHAR(32) , 
		  COMMONNAME VARCHAR(64) , 
		  EMAIL VARCHAR(128) , 
		  FAXPHONE VARCHAR(32) , 
		  GIVENNAME VARCHAR(128) , 
		  HOMEPHONE VARCHAR(32) , 
		  MOBILEPHONE VARCHAR(32) , 
		  PAGERPHONE VARCHAR(32) , 
		  PADDRESS VARCHAR(512) , 
		  SURNAME VARCHAR(128) , 
		  TIMEZONE VARCHAR(128) , 
		  CLOCALEID SMALLINT , 
		  PRODLOCALE VARCHAR(64) , 
		  OBJID VARCHAR(1024) , 
		  USEACCESSIBILITY DECIMAL(1,0) WITH DEFAULT 0 , 
		  USERNAME VARCHAR(128) , 
		  ORIENTATION SMALLINT , 
		  HORIZRENDERLIMIT INTEGER , 
		  VERTRENDERLIMIT INTEGER , 
		  MOBILEDEVID VARCHAR(512) , 
		  NOTIFICATIONEMAIL VARCHAR(512) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS1

ALTER TABLE CMOBJPROPS1 
	ADD CONSTRAINT PK_CMOBJPROPS1 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS10
------------------------------------------------
 

CREATE TABLE CMOBJPROPS10  (
		  CMID INTEGER NOT NULL , 
		  CONTACTEMAIL VARCHAR(128) , 
		  CONTACT CLOB(4000) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS10

ALTER TABLE CMOBJPROPS10 
	ADD CONSTRAINT PK_CMOBJPROPS10 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS11
------------------------------------------------
 

CREATE TABLE CMOBJPROPS11  (
		  CMID INTEGER NOT NULL , 
		  STATUSID SMALLINT , 
		  EVENTID VARCHAR(45) , 
		  OWNEREVENTID VARCHAR(45) , 
		  DISPATCHERID VARCHAR(50) , 
		  MAXDETAILSEVTY SMALLINT , 
		  SCHEDTRIGNAME VARCHAR(512) , 
		  SCHEDTYPE SMALLINT , 
		  RESTARTEVENTID VARCHAR(45) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS11

ALTER TABLE CMOBJPROPS11 
	ADD CONSTRAINT PK_CMOBJPROPS11 PRIMARY KEY
		(CMID);



-- DDL Statements for indexes on Table CMOBJPROPS11

CREATE INDEX IDX_CMOWNEREVENTID ON CMOBJPROPS11 
		(OWNEREVENTID ASC)
		ALLOW REVERSE SCANS;

-- DDL Statements for indexes on Table CMOBJPROPS11

CREATE INDEX IDX_CMRESTARTID ON CMOBJPROPS11 
		(RESTARTEVENTID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table CMOBJPROPS13
------------------------------------------------
 

CREATE TABLE CMOBJPROPS13  (
		  CMID INTEGER NOT NULL , 
		  ORD INTEGER NOT NULL , 
		  PARMNAME VARCHAR(512) NOT NULL , 
		  CPARMVALUE BLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS13

ALTER TABLE CMOBJPROPS13 
	ADD CONSTRAINT PK_CMOBJPROPS13 PRIMARY KEY
		(CMID,
		 ORD);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS14
------------------------------------------------
 

CREATE TABLE CMOBJPROPS14  (
		  CMID INTEGER NOT NULL , 
		  RELATED CLOB(1073741824) LOGGED NOT COMPACT , 
		  MYPAGE CLOB(1073741824) LOGGED NOT COMPACT , 
		  RETENTION CLOB(1073741824) LOGGED NOT COMPACT , 
		  RECIPSEMAIL CLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS14

ALTER TABLE CMOBJPROPS14 
	ADD CONSTRAINT PK_CMOBJPROPS14 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS15
------------------------------------------------
 

CREATE TABLE CMOBJPROPS15  (
		  CMID INTEGER NOT NULL , 
		  BRSHIAFFINECONS INTEGER , 
		  BRSAFFINECONS INTEGER , 
		  BRSMAXPROCS INTEGER , 
		  METADATAMODEL CLOB(4000) LOGGED NOT COMPACT , 
		  BRSEXECTIMELIMIT INTEGER , 
		  BRSDATASOURCECHG TIMESTAMP )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS15

ALTER TABLE CMOBJPROPS15 
	ADD CONSTRAINT PK_CMOBJPROPS15 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS16
------------------------------------------------
 

CREATE TABLE CMOBJPROPS16  (
		  CMID INTEGER NOT NULL , 
		  RSHIAFFINECONS INTEGER , 
		  RSAFFINECONS INTEGER , 
		  RSMAXPROCS INTEGER , 
		  RSQUEUELIMIT INTEGER , 
		  RUNNINGSTATE SMALLINT , 
		  ADVSETTINGS CLOB(4000) LOGGED NOT COMPACT , 
		  RSEXECTIMELIMIT INTEGER , 
		  ROUTINGTABLE BLOB(1048576) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS16

ALTER TABLE CMOBJPROPS16 
	ADD CONSTRAINT PK_CMOBJPROPS16 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS17
------------------------------------------------
 

CREATE TABLE CMOBJPROPS17  (
		  CMID INTEGER NOT NULL , 
		  NONPEAKBEGINHOUR SMALLINT , 
		  NONPEAKMAXJOBS INTEGER , 
		  PEAKBEGINHOUR SMALLINT , 
		  PEAKMAXJOBS INTEGER , 
		  NEWNONPEAKBEGINHOUR SMALLINT , 
		  NEWNONPEAKMAXJOBS INTEGER , 
		  NEWPEAKBEGINHOUR SMALLINT , 
		  NEWPEAKMAXJOBS INTEGER , 
		  USERCAPABILITY SMALLINT , 
		  STARTACTIVE DECIMAL(1,0) , 
		  COMPONENTID SMALLINT , 
		  PREVIMGLOCATION VARCHAR(255) , 
		  RESRCELOCATION VARCHAR(255) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS17

ALTER TABLE CMOBJPROPS17 
	ADD CONSTRAINT PK_CMOBJPROPS17 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS18
------------------------------------------------
 

CREATE TABLE CMOBJPROPS18  (
		  CMID INTEGER NOT NULL , 
		  OUTPUTREFS CLOB(1048576) LOGGED NOT COMPACT , 
		  PATHS CLOB(1048576) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS18

ALTER TABLE CMOBJPROPS18 
	ADD CONSTRAINT PK_CMOBJPROPS18 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS2
------------------------------------------------
 

CREATE TABLE CMOBJPROPS2  (
		  CMID INTEGER NOT NULL , 
		  TASKID VARCHAR(32) , 
		  STARTDATE TIMESTAMP , 
		  ENDDATE TIMESTAMP , 
		  ENDTYPE SMALLINT , 
		  EVERYNPERIODS INTEGER , 
		  DAILYPERIOD SMALLINT , 
		  MONTHLYABSDAY SMALLINT , 
		  MONTHLYRELDAY SMALLINT , 
		  MONTHLYRELWEEK SMALLINT , 
		  TYPE SMALLINT , 
		  YEARLYABSDAY SMALLINT , 
		  YEARLYABSMONTH SMALLINT , 
		  YEARLYRELDAY SMALLINT , 
		  YEARLYRELMONTH SMALLINT , 
		  YEARLYRELWEEK SMALLINT , 
		  ACTIVE DECIMAL(1,0) NOT NULL WITH DEFAULT 0 , 
		  WEEKLYMONDAY DECIMAL(1,0) NOT NULL WITH DEFAULT 0 , 
		  WEEKLYTUESDAY DECIMAL(1,0) NOT NULL WITH DEFAULT 0 , 
		  WEEKLYWEDNESDAY DECIMAL(1,0) NOT NULL WITH DEFAULT 0 , 
		  WEEKLYTHURSDAY DECIMAL(1,0) NOT NULL WITH DEFAULT 0 , 
		  WEEKLYFRIDAY DECIMAL(1,0) NOT NULL WITH DEFAULT 0 , 
		  WEEKLYSATURDAY DECIMAL(1,0) NOT NULL WITH DEFAULT 0 , 
		  WEEKLYSUNDAY DECIMAL(1,0) NOT NULL WITH DEFAULT 0 , 
		  PRIORITY INTEGER )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS2

ALTER TABLE CMOBJPROPS2 
	ADD CONSTRAINT PK_CMOBJPROPS2 PRIMARY KEY
		(CMID);



-- DDL Statements for indexes on Table CMOBJPROPS2

CREATE INDEX IDX_PRIORITY ON CMOBJPROPS2 
		(PRIORITY ASC)
		ALLOW REVERSE SCANS;

-- DDL Statements for indexes on Table CMOBJPROPS2

CREATE INDEX IDX_TASKID ON CMOBJPROPS2 
		(TASKID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table CMOBJPROPS20
------------------------------------------------
 

CREATE TABLE CMOBJPROPS20  (
		  CMID INTEGER NOT NULL , 
		  EXECLOCALEID SMALLINT , 
		  EXECFORMAT SMALLINT , 
		  EXECPAGEORIENT SMALLINT , 
		  EXECPROMPT DECIMAL(1,0) NOT NULL WITH DEFAULT 1 , 
		  DEFPORTACT SMALLINT , 
		  ALLOWSUBSCRIBE DECIMAL(1,0) , 
		  ALLOWNOTIFICATION DECIMAL(1,0) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS20

ALTER TABLE CMOBJPROPS20 
	ADD CONSTRAINT PK_CMOBJPROPS20 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS23
------------------------------------------------
 

CREATE TABLE CMOBJPROPS23  (
		  CMID INTEGER NOT NULL , 
		  LSAUDITADMINLVL SMALLINT , 
		  LSAUDITLVL SMALLINT , 
		  LSAUDITOTHERLVL SMALLINT , 
		  LSAUDITUSAGELVL SMALLINT , 
		  LSAUDITNATIVEQRY DECIMAL(1,0) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS23

ALTER TABLE CMOBJPROPS23 
	ADD CONSTRAINT PK_CMOBJPROPS23 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS24
------------------------------------------------
 

CREATE TABLE CMOBJPROPS24  (
		  CMID INTEGER NOT NULL , 
		  LOCATION VARCHAR(1024) , 
		  MODELNAME VARCHAR(512) , 
		  PRINTERADDRESS VARCHAR(2048) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS24

ALTER TABLE CMOBJPROPS24 
	ADD CONSTRAINT PK_CMOBJPROPS24 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS25
------------------------------------------------
 

CREATE TABLE CMOBJPROPS25  (
		  CMID INTEGER NOT NULL , 
		  DEPLOYOBJECT CLOB(4000) LOGGED NOT COMPACT , 
		  DEPLOYOBJANC CLOB(1048576) LOGGED NOT COMPACT , 
		  DEPLOYOBJCLASSID SMALLINT , 
		  DEPLOYOBJDEFNAME VARCHAR(255) , 
		  DEPLOYOBJDEFSTATUS SMALLINT , 
		  DEPLOYOBJUSAGE SMALLINT , 
		  MESSAGE BLOB(1048576) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS25

ALTER TABLE CMOBJPROPS25 
	ADD CONSTRAINT PK_CMOBJPROPS25 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS26
------------------------------------------------
 

CREATE TABLE CMOBJPROPS26  (
		  CMID INTEGER NOT NULL , 
		  DELIVOPTIONS CLOB(1048576) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS26

ALTER TABLE CMOBJPROPS26 
	ADD CONSTRAINT PK_CMOBJPROPS26 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS27
------------------------------------------------
 

CREATE TABLE CMOBJPROPS27  (
		  CMID INTEGER NOT NULL , 
		  CUBECONTNAME VARCHAR(2048) , 
		  GATEWAY VARCHAR(1024) , 
		  HASPROMPTS DECIMAL(1,0) NOT NULL WITH DEFAULT 0 , 
		  PPOPTIONS CLOB(4000) LOGGED NOT COMPACT , 
		  DATABLOCKS BLOB(1073741824) LOGGED NOT COMPACT , 
		  PPDEFPORTACT SMALLINT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS27

ALTER TABLE CMOBJPROPS27 
	ADD CONSTRAINT PK_CMOBJPROPS27 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS28
------------------------------------------------
 

CREATE TABLE CMOBJPROPS28  (
		  CMID INTEGER NOT NULL , 
		  EVENTKEY CLOB(4000) LOGGED NOT COMPACT , 
		  EVENTTYPES CLOB(4000) LOGGED NOT COMPACT , 
		  FILTERDATAITEM VARCHAR(512) , 
		  PARMASSIGN BLOB(1048576) LOGGED NOT COMPACT , 
		  SEQUENCING SMALLINT , 
		  ALLOWNOTIFICATION DECIMAL(1,0) , 
		  DEFPORTACTION SMALLINT , 
		  RUNCOND SMALLINT , 
		  SPEC CLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS28

ALTER TABLE CMOBJPROPS28 
	ADD CONSTRAINT PK_CMOBJPROPS28 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS3
------------------------------------------------
 

CREATE TABLE CMOBJPROPS3  (
		  CMID INTEGER NOT NULL , 
		  PROPNAME VARCHAR(50) NOT NULL , 
		  LOCALEID SMALLINT NOT NULL , 
		  VALUE VARCHAR(3700) , 
		  ISDEFAULT DECIMAL(1,0) , 
		  MAPDLOCALEID SMALLINT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS3

ALTER TABLE CMOBJPROPS3 
	ADD CONSTRAINT PK_CMOBJPROPS3 PRIMARY KEY
		(CMID,
		 PROPNAME,
		 LOCALEID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS30
------------------------------------------------
 

CREATE TABLE CMOBJPROPS30  (
		  CMID INTEGER NOT NULL , 
		  HANDLE VARCHAR(255) , 
		  BINDING CLOB(1048576) LOGGED NOT COMPACT , 
		  REGISTRATION CLOB(65536) LOGGED NOT COMPACT , 
		  SERVICEDESCR CLOB(1048576) LOGGED NOT COMPACT , 
		  LAYOUT CLOB(1048576) LOGGED NOT COMPACT , 
		  REQUIREDCAP CLOB(1048576) LOGGED NOT COMPACT , 
		  CANCUSTOMIZE DECIMAL(1,0) , 
		  CONTEXT CLOB(65536) LOGGED NOT COMPACT , 
		  DEPLOYREFS CLOB(1048576) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS30

ALTER TABLE CMOBJPROPS30 
	ADD CONSTRAINT PK_CMOBJPROPS30 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS31
------------------------------------------------
 

CREATE TABLE CMOBJPROPS31  (
		  CMID INTEGER NOT NULL , 
		  ASAUDITLVL SMALLINT , 
		  BRSAUDITLVL SMALLINT , 
		  CMSAUDITLVL SMALLINT , 
		  DISPAUDITLVL SMALLINT , 
		  DSAUDITLVL SMALLINT , 
		  EMSAUDITLVL SMALLINT , 
		  JSAUDITLVL SMALLINT , 
		  MDSAUDITLVL SMALLINT , 
		  MMSAUDITLVL SMALLINT , 
		  MSAUDITLVL SMALLINT , 
		  PACSAUDITLVL SMALLINT , 
		  PDSAUDITLVL SMALLINT , 
		  PRSAUDITLVL SMALLINT , 
		  PSAUDITLVL SMALLINT , 
		  PTSAUDITLVL SMALLINT , 
		  RSAUDITLVL SMALLINT , 
		  SSAUDITLVL SMALLINT , 
		  BRSAUDITNATIVEQRY DECIMAL(1,0) , 
		  RSAUDITNATIVEQRY DECIMAL(1,0) , 
		  DISAUDITLVL SMALLINT , 
		  RSDATASOURCECHG TIMESTAMP , 
		  IDSAUDITLVL SMALLINT , 
		  ISSAUDITLVL SMALLINT , 
		  IUSAUDITLVL SMALLINT , 
		  RDSAUDITLVL SMALLINT , 
		  RDSMAXDATASIZE INTEGER , 
		  MBSAUDITLVL SMALLINT , 
		  DDSAUDITLVL SMALLINT , 
		  DDSLISPERPRCSR INTEGER , 
		  DMSAUDITLVL SMALLINT , 
		  MISAUDITLVL SMALLINT , 
		  MDSAFFINECONNECTIONS INTEGER , 
		  MDSNONAFFINECONNCTS INTEGER , 
		  MDSPEAKCONS INTEGER , 
		  MDSPEAKNONAFFINECONNCTS INTEGER , 
		  MDSPEAKMAXPROCS INTEGER , 
		  MDSMAXPROCESSES INTEGER , 
		  MDSEXECUTIONTIMELIMIT INTEGER , 
		  MDSQUEUELIMIT INTEGER , 
		  MDINFOURI CLOB(4000) LOGGED NOT COMPACT , 
		  DIMSAUDITLVL INTEGER )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS31

ALTER TABLE CMOBJPROPS31 
	ADD CONSTRAINT PK_CMOBJPROPS31 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS32
------------------------------------------------
 

CREATE TABLE CMOBJPROPS32  (
		  CMID INTEGER NOT NULL , 
		  STOREDPROCNAME VARCHAR(255) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS32

ALTER TABLE CMOBJPROPS32 
	ADD CONSTRAINT PK_CMOBJPROPS32 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS33
------------------------------------------------
 

CREATE TABLE CMOBJPROPS33  (
		  CMID INTEGER NOT NULL , 
		  NAME VARCHAR(255) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS33

ALTER TABLE CMOBJPROPS33 
	ADD CONSTRAINT PK_CMOBJPROPS33 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS34
------------------------------------------------
 

CREATE TABLE CMOBJPROPS34  (
		  CMID INTEGER NOT NULL , 
		  ACTION SMALLINT , 
		  BOOKMARKITEM VARCHAR(255) , 
		  BOOKMARKTEXT VARCHAR(255) , 
		  DRILLPARMASSIGN BLOB(1048576) LOGGED NOT COMPACT , 
		  SCOPE BLOB(1048576) LOGGED NOT COMPACT , 
		  SPEC CLOB(1073741824) LOGGED NOT COMPACT , 
		  TARGETOPTIONS CLOB(1048576) LOGGED NOT COMPACT , 
		  DEPLOYREFS CLOB(1048576) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS34

ALTER TABLE CMOBJPROPS34 
	ADD CONSTRAINT PK_CMOBJPROPS34 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS35
------------------------------------------------
 

CREATE TABLE CMOBJPROPS35  (
		  CMID INTEGER NOT NULL , 
		  BINDINGNAME VARCHAR(512) , 
		  INPUTMESSNAME VARCHAR(512) , 
		  OPERATIONNAME VARCHAR(512) , 
		  OUTPUTMESSNAME VARCHAR(512) , 
		  SERVICENAME VARCHAR(512) , 
		  BULKEVENTS DECIMAL(1,0) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS35

ALTER TABLE CMOBJPROPS35 
	ADD CONSTRAINT PK_CMOBJPROPS35 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS36
------------------------------------------------
 

CREATE TABLE CMOBJPROPS36  (
		  CMID INTEGER NOT NULL , 
		  ACTION SMALLINT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS36

ALTER TABLE CMOBJPROPS36 
	ADD CONSTRAINT PK_CMOBJPROPS36 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS37
------------------------------------------------
 

CREATE TABLE CMOBJPROPS37  (
		  CMID INTEGER NOT NULL , 
		  ROUTINGHINTS CLOB(4000) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS37

ALTER TABLE CMOBJPROPS37 
	ADD CONSTRAINT PK_CMOBJPROPS37 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS38
------------------------------------------------
 

CREATE TABLE CMOBJPROPS38  (
		  CMID INTEGER NOT NULL , 
		  CTITEMCOUNTDEFAULT INTEGER , 
		  CTITEMCOUNTLIMIT INTEGER , 
		  MBRITEMCOUNTDEFAULT INTEGER , 
		  MBRITEMCOUNTLIMIT INTEGER )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS38

ALTER TABLE CMOBJPROPS38 
	ADD CONSTRAINT PK_CMOBJPROPS38 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS39
------------------------------------------------
 

CREATE TABLE CMOBJPROPS39  (
		  PROPID SMALLINT NOT NULL , 
		  CMID INTEGER NOT NULL , 
		  VALUE SMALLINT NOT NULL )   
		 IN CTBS_4K ; 






-- DDL Statements for indexes on Table CMOBJPROPS39

CREATE INDEX IDX_CMOBJPROPS39 ON CMOBJPROPS39 
		(CMID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table CMOBJPROPS4
------------------------------------------------
 

CREATE TABLE CMOBJPROPS4  (
		  CMID INTEGER NOT NULL , 
		  HEIGHT VARCHAR(20) , 
		  WIDTH VARCHAR(20) , 
		  UNIT SMALLINT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS4

ALTER TABLE CMOBJPROPS4 
	ADD CONSTRAINT PK_CMOBJPROPS4 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS40
------------------------------------------------
 

CREATE TABLE CMOBJPROPS40  (
		  CMID INTEGER NOT NULL , 
		  APPGUID VARCHAR(50) , 
		  APPID VARCHAR(512) , 
		  APPSTATE SMALLINT , 
		  APPURL CLOB(4000) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS40

ALTER TABLE CMOBJPROPS40 
	ADD CONSTRAINT PK_CMOBJPROPS40 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS41
------------------------------------------------
 

CREATE TABLE CMOBJPROPS41  (
		  CMID INTEGER NOT NULL , 
		  DEPTH INTEGER , 
		  ITEMID VARCHAR(512) , 
		  PARENTID VARCHAR(512) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS41

ALTER TABLE CMOBJPROPS41 
	ADD CONSTRAINT PK_CMOBJPROPS41 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS42
------------------------------------------------
 

CREATE TABLE CMOBJPROPS42  (
		  CMID INTEGER NOT NULL , 
		  SPEC CLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS42

ALTER TABLE CMOBJPROPS42 
	ADD CONSTRAINT PK_CMOBJPROPS42 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS43
------------------------------------------------
 

CREATE TABLE CMOBJPROPS43  (
		  CMID INTEGER NOT NULL , 
		  SPEC CLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS43

ALTER TABLE CMOBJPROPS43 
	ADD CONSTRAINT PK_CMOBJPROPS43 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS44
------------------------------------------------
 

CREATE TABLE CMOBJPROPS44  (
		  CMID INTEGER NOT NULL , 
		  RDSGATEWMAPPING BLOB(1048576) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS44

ALTER TABLE CMOBJPROPS44 
	ADD CONSTRAINT PK_CMOBJPROPS44 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS45
------------------------------------------------
 

CREATE TABLE CMOBJPROPS45  (
		  CMID INTEGER NOT NULL , 
		  LINK SMALLINT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS45

ALTER TABLE CMOBJPROPS45 
	ADD CONSTRAINT PK_CMOBJPROPS45 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS46
------------------------------------------------
 

CREATE TABLE CMOBJPROPS46  (
		  CMID INTEGER NOT NULL , 
		  DOCTYPE VARCHAR(512) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS46

ALTER TABLE CMOBJPROPS46 
	ADD CONSTRAINT PK_CMOBJPROPS46 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS47
------------------------------------------------
 

CREATE TABLE CMOBJPROPS47  (
		  CMID INTEGER NOT NULL , 
		  SYSTEMMETRIC SMALLINT , 
		  PROPERTIES BLOB(1048576) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS47

ALTER TABLE CMOBJPROPS47 
	ADD CONSTRAINT PK_CMOBJPROPS47 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS48
------------------------------------------------
 

CREATE TABLE CMOBJPROPS48  (
		  CMID INTEGER NOT NULL , 
		  ASCONNECTIONS INTEGER , 
		  CMSCONNECTIONS INTEGER , 
		  DDSCONNECTIONS INTEGER , 
		  DISCONNECTIONS INTEGER , 
		  DSCONNECTIONS INTEGER , 
		  IDSCONNECTIONS INTEGER , 
		  ISSCONNECTIONS INTEGER , 
		  IUSCONNECTIONS INTEGER , 
		  JSCONNECTIONS INTEGER , 
		  MBSCONNECTIONS INTEGER , 
		  MMSCONNECTIONS INTEGER , 
		  PACSCONNECTIONS INTEGER , 
		  PDSCONNECTIONS INTEGER , 
		  PRSCONNECTIONS INTEGER , 
		  PTSCONNECTIONS INTEGER , 
		  BRSCHHOTSPOTLIMIT INTEGER , 
		  RSCHHOTSPOTLIMIT INTEGER , 
		  CAPACITY DOUBLE , 
		  LOADBALMODE SMALLINT , 
		  DMSCONNECTIONS INTEGER , 
		  MISCONNECTIONS INTEGER , 
		  DSCOMPATTACHLIMIT INTEGER )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS48

ALTER TABLE CMOBJPROPS48 
	ADD CONSTRAINT PK_CMOBJPROPS48 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS49
------------------------------------------------
 

CREATE TABLE CMOBJPROPS49  (
		  CMID INTEGER NOT NULL , 
		  URI CLOB(4000) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS49

ALTER TABLE CMOBJPROPS49 
	ADD CONSTRAINT PK_CMOBJPROPS49 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS5
------------------------------------------------
 

CREATE TABLE CMOBJPROPS5  (
		  CMID INTEGER NOT NULL , 
		  ACTEXECTIME TIMESTAMP , 
		  ACTCOMPTIME TIMESTAMP , 
		  REQEXECTIME TIMESTAMP , 
		  USERREF CLOB(4000) LOGGED NOT COMPACT , 
		  DETAILTIME TIMESTAMP , 
		  DETAIL CLOB(1048576) LOGGED NOT COMPACT , 
		  SEVERITY SMALLINT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS5

ALTER TABLE CMOBJPROPS5 
	ADD CONSTRAINT PK_CMOBJPROPS5 PRIMARY KEY
		(CMID);



-- DDL Statements for indexes on Table CMOBJPROPS5

CREATE INDEX IDX_REQEXECTIME ON CMOBJPROPS5 
		(REQEXECTIME ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table CMOBJPROPS50
------------------------------------------------
 

CREATE TABLE CMOBJPROPS50  (
		  CMID INTEGER NOT NULL , 
		  CONTEXT BLOB(1073741824) LOGGED NOT COMPACT , 
		  CONTEXTCOUNT INTEGER , 
		  LASTPAGE VARCHAR(512) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS50

ALTER TABLE CMOBJPROPS50 
	ADD CONSTRAINT PK_CMOBJPROPS50 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS51
------------------------------------------------
 

CREATE TABLE CMOBJPROPS51  (
		  CMID INTEGER NOT NULL , 
		  SERVERGROUP VARCHAR(512) , 
		  RUNASOWNER DECIMAL(1,0) , 
		  CANBURST DECIMAL(1,0) , 
		  SCHEDTRIGNAME VARCHAR(255) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS51

ALTER TABLE CMOBJPROPS51 
	ADD CONSTRAINT PK_CMOBJPROPS51 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS52
------------------------------------------------
 

CREATE TABLE CMOBJPROPS52  (
		  CMID INTEGER NOT NULL , 
		  CONNECTSTR VARCHAR(2048) , 
		  ISOLEVEL SMALLINT , 
		  QUALIFIER SMALLINT , 
		  REPLACEMENT VARCHAR(512) , 
		  CLOSECONNECTCMD CLOB(1048576) LOGGED NOT COMPACT , 
		  OPENCONNECTCMD CLOB(1048576) LOGGED NOT COMPACT , 
		  CLOSESESSCMD CLOB(1048576) LOGGED NOT COMPACT , 
		  OPENSESSCMD CLOB(1048576) LOGGED NOT COMPACT , 
		  NOTIFYONCHANGE DECIMAL(1,0) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS52

ALTER TABLE CMOBJPROPS52 
	ADD CONSTRAINT PK_CMOBJPROPS52 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS53
------------------------------------------------
 

CREATE TABLE CMOBJPROPS53  (
		  CMID INTEGER NOT NULL , 
		  SEQUENCING SMALLINT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS53

ALTER TABLE CMOBJPROPS53 
	ADD CONSTRAINT PK_CMOBJPROPS53 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS54
------------------------------------------------
 

CREATE TABLE CMOBJPROPS54  (
		  CMID INTEGER NOT NULL , 
		  FORMAT SMALLINT , 
		  OLOCALEID SMALLINT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS54

ALTER TABLE CMOBJPROPS54 
	ADD CONSTRAINT PK_CMOBJPROPS54 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS55
------------------------------------------------
 

CREATE TABLE CMOBJPROPS55  (
		  CMID INTEGER NOT NULL , 
		  ICONURI VARCHAR(2000) , 
		  UCPOLICIES BLOB(1048576) LOGGED NOT COMPACT , 
		  HIDDEN DECIMAL(1,0) NOT NULL WITH DEFAULT 0 )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS55

ALTER TABLE CMOBJPROPS55 
	ADD CONSTRAINT PK_CMOBJPROPS55 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS56
------------------------------------------------
 

CREATE TABLE CMOBJPROPS56  (
		  CMID INTEGER NOT NULL , 
		  SPEC CLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS56

ALTER TABLE CMOBJPROPS56 
	ADD CONSTRAINT PK_CMOBJPROPS56 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS57
------------------------------------------------
 

CREATE TABLE CMOBJPROPS57  (
		  CMID INTEGER NOT NULL , 
		  SPEC CLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS57

ALTER TABLE CMOBJPROPS57 
	ADD CONSTRAINT PK_CMOBJPROPS57 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS58
------------------------------------------------
 

CREATE TABLE CMOBJPROPS58  (
		  CMID INTEGER NOT NULL , 
		  PDSELISTAXSCACHE INTEGER , 
		  PDSSHOWCELLANN DECIMAL(1,0) , 
		  PDSMAXPROCS INTEGER , 
		  PPSHIAFFINECONS INTEGER , 
		  PPSAFFINECONS INTEGER , 
		  PPSAUDITLEVEL SMALLINT , 
		  PPSQUEUELIMIT INTEGER , 
		  PPSEXECTIMELIMIT INTEGER , 
		  BRSPDFCHARENC SMALLINT , 
		  BRSPDFCOMPRSLVL INTEGER , 
		  BRSPDFCOMPRSTYPE SMALLINT , 
		  BRSPDFEMBEDFONTS SMALLINT , 
		  RSPDFCHARENC SMALLINT , 
		  RSPDFCOMPRSLVL INTEGER , 
		  RSPDFCOMPRSTYPE SMALLINT , 
		  RSPDFEMBEDFONTS SMALLINT , 
		  DMSAFFINECONNECTIONS INTEGER , 
		  DMSEXECUTIONTIMELIMIT INTEGER , 
		  DMSMAXPROCESSES INTEGER , 
		  DMSNONAFFINECONNCTS INTEGER , 
		  DMSPEAKMAXPROCESSES INTEGER , 
		  DMSPEAKNONAFFINECONNCTS INTEGER , 
		  DMSQUEUELIMIT INTEGER , 
		  PERDOCVERSRETAGE VARCHAR(50) , 
		  PERDOCVERSRETCOUNT INTEGER , 
		  EDITION VARCHAR(20) , 
		  EDITIONS BLOB(10485760) LOGGED NOT COMPACT , 
		  DIMSAFFINECONNECTIONS INTEGER , 
		  DIMSEXECUTIONTIMELIMIT INTEGER , 
		  DIMSMAXPROCESSES INTEGER , 
		  DIMSQUEUELIMIT INTEGER , 
		  GLOSSARYURI CLOB(4000) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS58

ALTER TABLE CMOBJPROPS58 
	ADD CONSTRAINT PK_CMOBJPROPS58 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS59
------------------------------------------------
 

CREATE TABLE CMOBJPROPS59  (
		  CMID INTEGER NOT NULL , 
		  CONFIGURATION CLOB(1048576) LOGGED NOT COMPACT , 
		  USERINTERFACE SMALLINT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS59

ALTER TABLE CMOBJPROPS59 
	ADD CONSTRAINT PK_CMOBJPROPS59 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS6
------------------------------------------------
 

CREATE TABLE CMOBJPROPS6  (
		  CMID INTEGER NOT NULL , 
		  URI CLOB(4000) LOGGED NOT COMPACT , 
		  TARGET CLOB(4000) LOGGED NOT COMPACT , 
		  STEPOBJECT CLOB(4000) LOGGED NOT COMPACT , 
		  BASE CLOB(4000) LOGGED NOT COMPACT , 
		  CREDENTIAL CLOB(4000) LOGGED NOT COMPACT , 
		  DISPATCHERPATH VARCHAR(3220) , 
		  PAGE CLOB(4000) LOGGED NOT COMPACT , 
		  CREDNAMESPACES CLOB(4000) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS6

ALTER TABLE CMOBJPROPS6 
	ADD CONSTRAINT PK_CMOBJPROPS6 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS60
------------------------------------------------
 

CREATE TABLE CMOBJPROPS60  (
		  CMID INTEGER NOT NULL , 
		  CONTEXT BLOB(1073741824) LOGGED NOT COMPACT , 
		  CONTEXTCOUNT INTEGER , 
		  LASTPAGE VARCHAR(512) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS60

ALTER TABLE CMOBJPROPS60 
	ADD CONSTRAINT PK_CMOBJPROPS60 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS61
------------------------------------------------
 

CREATE TABLE CMOBJPROPS61  (
		  CMID INTEGER NOT NULL , 
		  BURSTKEY VARCHAR(3982) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS61

ALTER TABLE CMOBJPROPS61 
	ADD CONSTRAINT PK_CMOBJPROPS61 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS62
------------------------------------------------
 

CREATE TABLE CMOBJPROPS62  (
		  CMID INTEGER NOT NULL , 
		  EXPIRATION TIMESTAMP , 
		  ALLOWANNOTATION DECIMAL(1,0) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS62

ALTER TABLE CMOBJPROPS62 
	ADD CONSTRAINT PK_CMOBJPROPS62 PRIMARY KEY
		(CMID);



-- DDL Statements for indexes on Table CMOBJPROPS62

CREATE INDEX IDX_EXPIRATION_62 ON CMOBJPROPS62 
		(EXPIRATION ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table CMOBJPROPS63
------------------------------------------------
 

CREATE TABLE CMOBJPROPS63  (
		  CMID INTEGER NOT NULL , 
		  SPEC CLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS63

ALTER TABLE CMOBJPROPS63 
	ADD CONSTRAINT PK_CMOBJPROPS63 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS64
------------------------------------------------
 

CREATE TABLE CMOBJPROPS64  (
		  CMID INTEGER NOT NULL , 
		  CONTENTTYPE VARCHAR(256) , 
		  DATASIZE INTEGER , 
		  DATACOMP DECIMAL(1,0) NOT NULL WITH DEFAULT 0 , 
		  DATAPROP BLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS64

ALTER TABLE CMOBJPROPS64 
	ADD CONSTRAINT PK_CMOBJPROPS64 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS65
------------------------------------------------
 

CREATE TABLE CMOBJPROPS65  (
		  CMID INTEGER NOT NULL , 
		  BURSTID VARCHAR(3869) , 
		  BURSTIDINDEX CHAR(44) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS65

ALTER TABLE CMOBJPROPS65 
	ADD CONSTRAINT PK_CMOBJPROPS65 PRIMARY KEY
		(CMID);



-- DDL Statements for indexes on Table CMOBJPROPS65

CREATE INDEX IDX_BURSTIDINDEX ON CMOBJPROPS65 
		(BURSTIDINDEX ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table CMOBJPROPS66
------------------------------------------------
 

CREATE TABLE CMOBJPROPS66  (
		  CMID INTEGER NOT NULL , 
		  DEFPORTACT SMALLINT , 
		  SPEC CLOB(1073741824) LOGGED NOT COMPACT , 
		  POWERPLAY8CONFIGURATION CLOB(1048576) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS66

ALTER TABLE CMOBJPROPS66 
	ADD CONSTRAINT PK_CMOBJPROPS66 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS67
------------------------------------------------
 

CREATE TABLE CMOBJPROPS67  (
		  CMID INTEGER NOT NULL , 
		  NONPEAKDEMANDBGNH INTEGER , 
		  PEAKDEMANDBEGINH INTEGER , 
		  ASPEAKCONS INTEGER , 
		  BRSPEAKAFFINECONS INTEGER , 
		  BRSPEAKMAXPROCS INTEGER , 
		  BRSPEAKNONAFFCONS INTEGER , 
		  CMSPEAKCONS INTEGER , 
		  DDSPEAKCONS INTEGER , 
		  DISPEAKCONS INTEGER , 
		  DMSPEAKCONS INTEGER , 
		  DSPEAKCONS INTEGER , 
		  IDSPEAKCONS INTEGER , 
		  ISSPEAKCONS INTEGER , 
		  IUSPEAKCONS INTEGER , 
		  JSPEAKCONS INTEGER , 
		  MBSPEAKCONS INTEGER , 
		  MISPEAKCONS INTEGER , 
		  MMSPEAKCONS INTEGER , 
		  PACSPEAKCONS INTEGER , 
		  PDSPEAKCONS INTEGER , 
		  PDSPEAKMAXPROCS INTEGER , 
		  PPSPEAKAFFINECONS INTEGER , 
		  PPSPEAKNONAFFCONS INTEGER , 
		  PRSPEAKCONS INTEGER , 
		  PTSPEAKCONS INTEGER , 
		  RSPEAKAFFINECONS INTEGER , 
		  RSPEAKMAXPROCS INTEGER , 
		  RSPEAKNONAFFCONS INTEGER , 
		  DIMSNONAFFINECONNCTS INTEGER , 
		  DIMSPEAKCONS INTEGER , 
		  DIMSPEAKMAXPROCS INTEGER , 
		  DIMSPEAKNONAFFINECONNCTS INTEGER )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS67

ALTER TABLE CMOBJPROPS67 
	ADD CONSTRAINT PK_CMOBJPROPS67 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS68
------------------------------------------------
 

CREATE TABLE CMOBJPROPS68  (
		  CMID INTEGER NOT NULL , 
		  SPEC CLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS68

ALTER TABLE CMOBJPROPS68 
	ADD CONSTRAINT PK_CMOBJPROPS68 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS69
------------------------------------------------
 

CREATE TABLE CMOBJPROPS69  (
		  CMID INTEGER NOT NULL , 
		  ORD INTEGER NOT NULL , 
		  PARMNAME VARCHAR(512) NOT NULL , 
		  CPARMVALUE BLOB(1073741824) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS69

ALTER TABLE CMOBJPROPS69 
	ADD CONSTRAINT PK_CMOBJPROPS69 PRIMARY KEY
		(CMID,
		 ORD);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS7
------------------------------------------------
 

CREATE TABLE CMOBJPROPS7  (
		  CMID INTEGER NOT NULL , 
		  EXECERROR CLOB(1073741824) LOGGED NOT COMPACT , 
		  CONFIGURATION CLOB(1073741824) LOGGED NOT COMPACT , 
		  PORTALPREFS CLOB(1073741824) LOGGED NOT COMPACT , 
		  CCREDENTIALS CLOB(1073741824) LOGGED NOT COMPACT , 
		  CMODEL BLOB(1073741824) LOGGED NOT COMPACT , 
		  SRC CLOB(1073741824) LOGGED NOT COMPACT , 
		  SPEC CLOB(1073741824) LOGGED NOT COMPACT , 
		  STATE CLOB(1073741824) LOGGED NOT COMPACT , 
		  GOVERNORS CLOB(1073741824) LOGGED NOT COMPACT , 
		  NAMESPFORMAT CLOB(4000) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS7

ALTER TABLE CMOBJPROPS7 
	ADD CONSTRAINT PK_CMOBJPROPS7 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS70
------------------------------------------------
 

CREATE TABLE CMOBJPROPS70  (
		  CMID INTEGER NOT NULL , 
		  CONTEXT CLOB(65536) LOGGED NOT COMPACT , 
		  DEPLOYREFS CLOB(1048576) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS70

ALTER TABLE CMOBJPROPS70 
	ADD CONSTRAINT PK_CMOBJPROPS70 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS71
------------------------------------------------
 

CREATE TABLE CMOBJPROPS71  (
		  CMID INTEGER NOT NULL , 
		  CONTEXT CLOB(65536) LOGGED NOT COMPACT , 
		  DEPLOYREFS CLOB(1048576) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS71

ALTER TABLE CMOBJPROPS71 
	ADD CONSTRAINT PK_CMOBJPROPS71 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS72
------------------------------------------------
 

CREATE TABLE CMOBJPROPS72  (
		  CMID INTEGER NOT NULL , 
		  CONTEXT CLOB(65536) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS72

ALTER TABLE CMOBJPROPS72 
	ADD CONSTRAINT PK_CMOBJPROPS72 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS73
------------------------------------------------
 

CREATE TABLE CMOBJPROPS73  (
		  CMID INTEGER NOT NULL , 
		  ALIASROOT VARCHAR(512) , 
		  URI CLOB(4000) LOGGED NOT COMPACT , 
		  UNIXURI CLOB(4000) LOGGED NOT COMPACT , 
		  WINDOWSURI CLOB(4000) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS73

ALTER TABLE CMOBJPROPS73 
	ADD CONSTRAINT PK_CMOBJPROPS73 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMOBJPROPS9
------------------------------------------------
 

CREATE TABLE CMOBJPROPS9  (
		  CMID INTEGER NOT NULL , 
		  ASOFTIME TIMESTAMP , 
		  CANBURST DECIMAL(1,0) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMOBJPROPS9

ALTER TABLE CMOBJPROPS9 
	ADD CONSTRAINT PK_CMOBJPROPS9 PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMPOLICIES
------------------------------------------------
 

CREATE TABLE CMPOLICIES  (
		  CMID INTEGER NOT NULL , 
		  POLICIES BLOB(102400) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMPOLICIES

ALTER TABLE CMPOLICIES 
	ADD CONSTRAINT PK_CMPOLICIES PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMVIEWED
------------------------------------------------
 

CREATE TABLE CMVIEWED  (
		  CMID INTEGER NOT NULL , 
		  OBJID CLOB(4000) LOGGED NOT COMPACT WITH DEFAULT '-' , 
		  VIEWED DECIMAL(1,0) WITH DEFAULT 0 )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMVIEWED

ALTER TABLE CMVIEWED 
	ADD CONSTRAINT PK_CMVIEWED PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMPROPERTIES
------------------------------------------------
 

CREATE TABLE CMPROPERTIES  (
		  PROPID SMALLINT NOT NULL , 
		  NAME VARCHAR(50) NOT NULL , 
		  DEF BLOB(10240) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMPROPERTIES

ALTER TABLE CMPROPERTIES 
	ADD CONSTRAINT PK_CMPROPERTIES PRIMARY KEY
		(PROPID);


------------------------------------------------
-- DDL Statements for table CMCLASSES
------------------------------------------------
 

CREATE TABLE CMCLASSES  (
		  CLASSID SMALLINT NOT NULL , 
		  NAME VARCHAR(50) NOT NULL , 
		  USAGE SMALLINT , 
		  DEF BLOB(102400) LOGGED NOT COMPACT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMCLASSES

ALTER TABLE CMCLASSES 
	ADD CONSTRAINT PK_CMCLASSES PRIMARY KEY
		(CLASSID);


------------------------------------------------
-- DDL Statements for table CMLOCALES
------------------------------------------------
 

CREATE TABLE CMLOCALES  (
		  LOCALEID SMALLINT NOT NULL , 
		  MAPDLOCALEID SMALLINT NOT NULL , 
		  LOCALE VARCHAR(20) NOT NULL )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMLOCALES

ALTER TABLE CMLOCALES 
	ADD CONSTRAINT PK_CMLOCALES PRIMARY KEY
		(LOCALEID);


------------------------------------------------
-- DDL Statements for table CMGUIDS
------------------------------------------------
 

CREATE TABLE CMGUIDS  (
		  CMID INTEGER NOT NULL , 
		  GUID VARCHAR(50) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMGUIDS

ALTER TABLE CMGUIDS 
	ADD CONSTRAINT PK_CMGUIDS PRIMARY KEY
		(CMID);


------------------------------------------------
-- DDL Statements for table CMREFNOORD1
------------------------------------------------
 

CREATE TABLE CMREFNOORD1  (
		  PROPID SMALLINT NOT NULL , 
		  CMID INTEGER NOT NULL , 
		  REFCMID INTEGER NOT NULL )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMREFNOORD1

ALTER TABLE CMREFNOORD1 
	ADD CONSTRAINT PK_CMREFNOORD1 PRIMARY KEY
		(CMID,
		 PROPID);



-- DDL Statements for indexes on Table CMREFNOORD1

CREATE INDEX IDX_CMREFNOORD1 ON CMREFNOORD1 
		(REFCMID ASC,
		 PROPID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table CMREFNOORD2
------------------------------------------------
 

CREATE TABLE CMREFNOORD2  (
		  CMID INTEGER NOT NULL , 
		  REFCMID INTEGER NOT NULL )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMREFNOORD2

ALTER TABLE CMREFNOORD2 
	ADD CONSTRAINT PK_CMREFNOORD2 PRIMARY KEY
		(CMID);



-- DDL Statements for indexes on Table CMREFNOORD2

CREATE INDEX IDX_CMREFNOORD2 ON CMREFNOORD2 
		(REFCMID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table CMREFORD1
------------------------------------------------
 

CREATE TABLE CMREFORD1  (
		  PROPID SMALLINT NOT NULL , 
		  CMID INTEGER NOT NULL , 
		  ORD INTEGER NOT NULL , 
		  REFCMID INTEGER NOT NULL )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMREFORD1

ALTER TABLE CMREFORD1 
	ADD CONSTRAINT PK_CMREFORD1 PRIMARY KEY
		(CMID,
		 PROPID,
		 ORD);



-- DDL Statements for indexes on Table CMREFORD1

CREATE INDEX IDX_CMREFORD1 ON CMREFORD1 
		(REFCMID ASC,
		 PROPID ASC,
		 ORD ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table CMREFORD2
------------------------------------------------
 

CREATE TABLE CMREFORD2  (
		  CMID INTEGER NOT NULL , 
		  ORD INTEGER NOT NULL , 
		  REFCMID INTEGER NOT NULL )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMREFORD2

ALTER TABLE CMREFORD2 
	ADD CONSTRAINT PK_CMREFORD2 PRIMARY KEY
		(CMID,
		 ORD);



-- DDL Statements for indexes on Table CMREFORD2

CREATE INDEX IDX_CMREFORD2 ON CMREFORD2 
		(REFCMID ASC,
		 ORD ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table CMNOTIFICATIONTABLE
------------------------------------------------
 

CREATE TABLE CMNOTIFICATIONTABLE  (
		  STOREID CHAR(33) NOT NULL , 
		  OPERATION VARCHAR(25) NOT NULL , 
		  CLASSNAME VARCHAR(25) NOT NULL , 
		  EVENTTIME TIMESTAMP NOT NULL )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMNOTIFICATIONTABLE

ALTER TABLE CMNOTIFICATIONTABLE 
	ADD CONSTRAINT PK_CMNOTIFICATION PRIMARY KEY
		(STOREID,
		 OPERATION,
		 EVENTTIME);


------------------------------------------------
-- DDL Statements for table CMDATAUPGRADE
------------------------------------------------
 

CREATE TABLE CMDATAUPGRADE  (
		  PLUGINNAME VARCHAR(255) NOT NULL , 
		  CI_PLUGINNAME VARCHAR(255) NOT NULL , 
		  VERSION VARCHAR(64) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMDATAUPGRADE

ALTER TABLE CMDATAUPGRADE 
	ADD CONSTRAINT PK_CMDATAUPGRADE PRIMARY KEY
		(CI_PLUGINNAME);


------------------------------------------------
-- DDL Statements for table CMSIZEINFO
------------------------------------------------
 

CREATE TABLE CMSIZEINFO  (
		  STOREID VARCHAR(255) NOT NULL , 
		  CLASSID SMALLINT NOT NULL , 
		  TOTALFORCLASSID SMALLINT NOT NULL , 
		  TOTALCOUNT BIGINT , 
		  TOTALSIZE BIGINT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table CMSIZEINFO

ALTER TABLE CMSIZEINFO 
	ADD CONSTRAINT PK_CMSIZEINFO PRIMARY KEY
		(STOREID,
		 TOTALFORCLASSID);


------------------------------------------------
-- DDL Statements for table NC_CONFIGURATION
------------------------------------------------
 

CREATE TABLE NC_CONFIGURATION  (
		  PROPERTY_KEY VARCHAR(255) NOT NULL , 
		  PROPERTY_VALUE VARCHAR(255) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_CONFIGURATION

ALTER TABLE NC_CONFIGURATION 
	ADD CONSTRAINT PN_CONFIGURATION PRIMARY KEY
		(PROPERTY_KEY);


------------------------------------------------
-- DDL Statements for table NC_CTMAP
------------------------------------------------
 

CREATE TABLE NC_CTMAP  (
		  OBJTYPE SMALLINT NOT NULL , 
		  CLASS VARCHAR(200) , 
		  TABLENAME VARCHAR(200) NOT NULL , 
		  HELPER VARCHAR(200) , 
		  REMOTECLASS VARCHAR(200) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_CTMAP

ALTER TABLE NC_CTMAP 
	ADD CONSTRAINT PN_CTMAP PRIMARY KEY
		(OBJTYPE);


------------------------------------------------
-- DDL Statements for table NC_DB_VERSION
------------------------------------------------
 

CREATE TABLE NC_DB_VERSION  (
		  DB_VERSION_ID INTEGER , 
		  BUILD VARCHAR(20) )   
		 IN CTBS_4K ; 





------------------------------------------------
-- DDL Statements for table NC_DELIVERYADDRESS
------------------------------------------------
 

CREATE TABLE NC_DELIVERYADDRESS  (
		  PK_DELADDRESS_ID INTEGER NOT NULL , 
		  DELIVERY_ADDRESS VARCHAR(100) , 
		  CHANNEL_TYPE INTEGER , 
		  IS_DEFAULT INTEGER NOT NULL , 
		  FK_RECIPIENT_ID INTEGER , 
		  ADDRESS_TYPE INTEGER )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_DELIVERYADDRESS

ALTER TABLE NC_DELIVERYADDRESS 
	ADD CONSTRAINT PN_DELIVERYADDRESS PRIMARY KEY
		(PK_DELADDRESS_ID);



-- DDL Statements for indexes on Table NC_DELIVERYADDRESS

CREATE INDEX I1N_DELIV_ADR ON NC_DELIVERYADDRESS 
		(FK_RECIPIENT_ID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table NC_EVENTSTATUS
------------------------------------------------
 

CREATE TABLE NC_EVENTSTATUS  (
		  PK_EVENT_ID CHAR(45) NOT NULL , 
		  EVENT_STATUS INTEGER NOT NULL , 
		  CONVERSATION INTEGER , 
		  SDS_INSTANCE_ID CHAR(32) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_EVENTSTATUS

ALTER TABLE NC_EVENTSTATUS 
	ADD CONSTRAINT PN_NC_EVENTSTATUS PRIMARY KEY
		(PK_EVENT_ID);


------------------------------------------------
-- DDL Statements for table NC_JMSQUEUE
------------------------------------------------
 

CREATE TABLE NC_JMSQUEUE  (
		  QUEUE_ENTRY_ID INTEGER NOT NULL , 
		  QUEUE_NAME VARCHAR(440) , 
		  QUEUE_ENTRY BLOB(524288000) LOGGED NOT COMPACT , 
		  SDS_INSTANCE_ID CHAR(32) , 
		  DATE_ENTERED DECIMAL(14,0) NOT NULL , 
		  REDELIVER_DATE DECIMAL(19,0) , 
		  REDELIVER_COUNT INTEGER NOT NULL WITH DEFAULT 0 )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_JMSQUEUE

ALTER TABLE NC_JMSQUEUE 
	ADD CONSTRAINT PN_NC_JMSQUEUE PRIMARY KEY
		(QUEUE_ENTRY_ID);



-- DDL Statements for indexes on Table NC_JMSQUEUE

CREATE INDEX IX_NC_JMSQUEUE ON NC_JMSQUEUE 
		(QUEUE_NAME ASC,
		 DATE_ENTERED ASC,
		 SDS_INSTANCE_ID ASC)
		ALLOW REVERSE SCANS;

-- DDL Statements for indexes on Table NC_JMSQUEUE

CREATE INDEX IX_NC_JMSQUEUE1 ON NC_JMSQUEUE 
		(QUEUE_NAME ASC,
		 SDS_INSTANCE_ID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table NC_JOBQUEUE
------------------------------------------------
 

CREATE TABLE NC_JOBQUEUE  (
		  PK_RUN_ID CHAR(45) NOT NULL , 
		  SERVICE_NAME CHAR(40) , 
		  SERVER_GROUP CHAR(40) , 
		  DATE_ENTERED DECIMAL(14,0) NOT NULL , 
		  JOB BLOB(524288000) LOGGED NOT COMPACT NOT NULL )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_JOBQUEUE

ALTER TABLE NC_JOBQUEUE 
	ADD CONSTRAINT PN_JOBQUEUE PRIMARY KEY
		(PK_RUN_ID);



-- DDL Statements for indexes on Table NC_JOBQUEUE

CREATE INDEX IN_JOBQ_SELECTOR ON NC_JOBQUEUE 
		(SERVICE_NAME ASC,
		 SERVER_GROUP ASC,
		 DATE_ENTERED ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table NC_MESSAGELINE
------------------------------------------------
 

CREATE TABLE NC_MESSAGELINE  (
		  FK_MESSAGESTRUCT_ID INTEGER NOT NULL , 
		  LINE_NO INTEGER NOT NULL , 
		  LINE_TYPE INTEGER )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_MESSAGELINE

ALTER TABLE NC_MESSAGELINE 
	ADD CONSTRAINT PN_MESSAGELINE PRIMARY KEY
		(LINE_NO,
		 FK_MESSAGESTRUCT_ID);



-- DDL Statements for indexes on Table NC_MESSAGELINE

CREATE INDEX I1N_MESSAGELINE ON NC_MESSAGELINE 
		(FK_MESSAGESTRUCT_ID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table NC_MESSAGELINE_ELEMENT
------------------------------------------------
 

CREATE TABLE NC_MESSAGELINE_ELEMENT  (
		  FK_MESSAGESTRUCT_ID INTEGER NOT NULL , 
		  ELEMENT_NUMBER INTEGER NOT NULL , 
		  LINE_NO INTEGER NOT NULL , 
		  TEXT VARCHAR(3000) , 
		  FK_BIE_TOPIC_ID INTEGER )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_MESSAGELINE_ELEMENT

ALTER TABLE NC_MESSAGELINE_ELEMENT 
	ADD CONSTRAINT PN_MESSAGELINE_ELE PRIMARY KEY
		(LINE_NO,
		 ELEMENT_NUMBER,
		 FK_MESSAGESTRUCT_ID);



-- DDL Statements for indexes on Table NC_MESSAGELINE_ELEMENT

CREATE INDEX I1N_MESSAGELINE_EL ON NC_MESSAGELINE_ELEMENT 
		(FK_MESSAGESTRUCT_ID ASC)
		ALLOW REVERSE SCANS;

-- DDL Statements for indexes on Table NC_MESSAGELINE_ELEMENT

CREATE INDEX I2N_MESSAGELINE_EL ON NC_MESSAGELINE_ELEMENT 
		(LINE_NO ASC,
		 FK_MESSAGESTRUCT_ID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table NC_MESSAGESTRUCT
------------------------------------------------
 

CREATE TABLE NC_MESSAGESTRUCT  (
		  PK_MS_ID INTEGER NOT NULL , 
		  FK_DYNREC_ID INTEGER , 
		  NAME VARCHAR(255) , 
		  DESCRIPTION VARCHAR(1000) , 
		  SOURCE VARCHAR(100) , 
		  SUBJECT VARCHAR(210) , 
		  MODCOUNT INTEGER WITH DEFAULT -1 , 
		  LASTMOD_BY VARCHAR(50) , 
		  CHANNEL_TYPE INTEGER , 
		  CONTACT VARCHAR(50) , 
		  CREDENTIAL VARCHAR(1024) , 
		  AVOID_DUPLICATION INTEGER NOT NULL WITH DEFAULT 0 )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_MESSAGESTRUCT

ALTER TABLE NC_MESSAGESTRUCT 
	ADD CONSTRAINT PN_MESSAGESTRUCT PRIMARY KEY
		(PK_MS_ID);



-- DDL Statements for indexes on Table NC_MESSAGESTRUCT

CREATE INDEX I1N_MESSAGESTRUCT ON NC_MESSAGESTRUCT 
		(FK_DYNREC_ID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table NC_METRICS
------------------------------------------------
 

CREATE TABLE NC_METRICS  (
		  NAME VARCHAR(255) NOT NULL , 
		  LASTMOD_TIME DECIMAL(19,0) NOT NULL WITH DEFAULT 0 , 
		  VALUE DECIMAL(19,0) NOT NULL WITH DEFAULT 0 , 
		  ACTIVE INTEGER NOT NULL WITH DEFAULT 0 )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_METRICS

ALTER TABLE NC_METRICS 
	ADD CONSTRAINT PN_METRICS PRIMARY KEY
		(NAME);


------------------------------------------------
-- DDL Statements for table NC_OBJECTCATALOGUE
------------------------------------------------
 

CREATE TABLE NC_OBJECTCATALOGUE  (
		  PK_OID INTEGER NOT NULL , 
		  NAME VARCHAR(255) , 
		  DESCRIPTION VARCHAR(1000) , 
		  SUBTYPE INTEGER , 
		  TYPE INTEGER NOT NULL , 
		  MODCOUNT INTEGER WITH DEFAULT -1 , 
		  CM_VERSION INTEGER WITH DEFAULT -1 )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_OBJECTCATALOGUE

ALTER TABLE NC_OBJECTCATALOGUE 
	ADD CONSTRAINT PN_OBJECTCATALOGUE PRIMARY KEY
		(PK_OID);


------------------------------------------------
-- DDL Statements for table NC_OBJECTID
------------------------------------------------
 

CREATE TABLE NC_OBJECTID  (
		  OBJECTID INTEGER NOT NULL )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_OBJECTID

ALTER TABLE NC_OBJECTID 
	ADD CONSTRAINT PN_NC_OBJECTID PRIMARY KEY
		(OBJECTID);


------------------------------------------------
-- DDL Statements for table NC_PERMISSION
------------------------------------------------
 

CREATE TABLE NC_PERMISSION  (
		  PK_PERMISSION_ID INTEGER NOT NULL , 
		  DESCRIPTION VARCHAR(30) NOT NULL )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_PERMISSION

ALTER TABLE NC_PERMISSION 
	ADD CONSTRAINT PN_PERMISSION PRIMARY KEY
		(PK_PERMISSION_ID);


------------------------------------------------
-- DDL Statements for table NC_RECIPIENT
------------------------------------------------
 

CREATE TABLE NC_RECIPIENT  (
		  PK_RECIPIENT_ID INTEGER NOT NULL , 
		  NAME VARCHAR(255) , 
		  DESCRIPTION VARCHAR(1000) , 
		  LASTMOD_BY CHAR(40) , 
		  LASTMOD_TIME TIMESTAMP NOT NULL WITH DEFAULT CURRENT TIMESTAMP , 
		  MODCOUNT INTEGER WITH DEFAULT -1 , 
		  TITLE VARCHAR(10) , 
		  FIRSTNAME VARCHAR(50) , 
		  MIDDLENAME VARCHAR(50) , 
		  LASTNAME VARCHAR(50) , 
		  PHONENUMBER VARCHAR(50) , 
		  JOBTITLE VARCHAR(50) , 
		  COMPANY VARCHAR(255) , 
		  DEPARTMENT VARCHAR(255) , 
		  OFFICE VARCHAR(255) , 
		  COUNTRY VARCHAR(50) , 
		  TIMEZONE VARCHAR(50) , 
		  TO_REDIRECT INTEGER NOT NULL , 
		  FK_REDIRECT_RID INTEGER , 
		  FK_REDIRECT_RGID INTEGER , 
		  IS_EXTERNAL INTEGER , 
		  IS_USEDEFAULTADDRESS INTEGER )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_RECIPIENT

ALTER TABLE NC_RECIPIENT 
	ADD CONSTRAINT PN_RECIPIENT PRIMARY KEY
		(PK_RECIPIENT_ID);


------------------------------------------------
-- DDL Statements for table NC_SCHEDULE
------------------------------------------------
 

CREATE TABLE NC_SCHEDULE  (
		  PK_SCHEDULE_ID INTEGER NOT NULL , 
		  NAME VARCHAR(255) , 
		  DESCRIPTION VARCHAR(1000) , 
		  LASTMOD_BY CHAR(40) , 
		  LASTMOD_TIME TIMESTAMP NOT NULL WITH DEFAULT CURRENT TIMESTAMP , 
		  MODCOUNT INTEGER WITH DEFAULT -1 , 
		  SCHEDULE_TYPE CHAR(6) , 
		  TIMEZONE VARCHAR(100) , 
		  START_DATE DECIMAL(19,0) , 
		  END_DATE DECIMAL(19,0) , 
		  REPEAT_FOREVER INTEGER , 
		  ACTIVE INTEGER , 
		  VALID_SCHEDULE INTEGER , 
		  USE_DAY_NUMBER INTEGER , 
		  DAY_OF_MONTH INTEGER , 
		  DAY_OF_WEEK INTEGER , 
		  DAY_OF_WEEK_IN_MONTH INTEGER , 
		  MONTH_OF_YEAR INTEGER , 
		  REPEAT_INTERVAL INTEGER , 
		  DAYS_OF_WEEK INTEGER , 
		  FIXED_INTERVAL_TYPE INTEGER , 
		  FIXED_INTERVAL_IN_MILLIS DECIMAL(19,0) , 
		  TRIGGER_ID VARCHAR(255) , 
		  PERIODICAL_PRODUCER_ID CHAR(33) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_SCHEDULE

ALTER TABLE NC_SCHEDULE 
	ADD CONSTRAINT PN_SCHEDULE PRIMARY KEY
		(PK_SCHEDULE_ID);


------------------------------------------------
-- DDL Statements for table NC_SCHEDULE_QUEUE
------------------------------------------------
 

CREATE TABLE NC_SCHEDULE_QUEUE  (
		  SCHEDULE_ID INTEGER NOT NULL , 
		  RUN_DATE DECIMAL(19,0) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_SCHEDULE_QUEUE

ALTER TABLE NC_SCHEDULE_QUEUE 
	ADD CONSTRAINT PN_SCHEDULE_QUEUEI PRIMARY KEY
		(SCHEDULE_ID);


------------------------------------------------
-- DDL Statements for table NC_SDS_INSTANCE
------------------------------------------------
 

CREATE TABLE NC_SDS_INSTANCE  (
		  PK_INSTANCE_ID CHAR(32) NOT NULL , 
		  PK_INSTANCE_URL VARCHAR(255) NOT NULL , 
		  LAST_UPDATE DECIMAL(14,0) NOT NULL , 
		  CLEANUP_INSTANCE_ID CHAR(32) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_SDS_INSTANCE

ALTER TABLE NC_SDS_INSTANCE 
	ADD CONSTRAINT PN_SDS_INSTANCE PRIMARY KEY
		(PK_INSTANCE_ID);


------------------------------------------------
-- DDL Statements for table NC_TASK
------------------------------------------------
 

CREATE TABLE NC_TASK  (
		  PK_TASK_ID INTEGER NOT NULL , 
		  NAME VARCHAR(255) , 
		  DESCRIPTION VARCHAR(1000) , 
		  FK_BIE_ID INTEGER , 
		  THRESHOLD INTEGER , 
		  WEIGHTS VARCHAR(200) , 
		  TASK_TYPE INTEGER , 
		  DATEFORMAT CHAR(19) , 
		  DETECTION_OPTION INTEGER , 
		  LASTMOD_TIME TIMESTAMP WITH DEFAULT CURRENT TIMESTAMP , 
		  MODCOUNT INTEGER WITH DEFAULT -1 , 
		  LASTMOD_BY CHAR(40) , 
		  LOCATION_ROOT VARCHAR(256) , 
		  OBJECT_CLASS VARCHAR(256) , 
		  OWNED_BY VARCHAR(256) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_TASK

ALTER TABLE NC_TASK 
	ADD CONSTRAINT PN_TASK PRIMARY KEY
		(PK_TASK_ID);


------------------------------------------------
-- DDL Statements for table NC_TASKSCHEDULE
------------------------------------------------
 

CREATE TABLE NC_TASKSCHEDULE  (
		  PK_TASKSCHEDULE_ID INTEGER NOT NULL , 
		  FK_TASK_ID INTEGER , 
		  NAME VARCHAR(255) , 
		  DESCRIPTION VARCHAR(1000) , 
		  LASTMOD_BY CHAR(40) , 
		  MODCOUNT INTEGER NOT NULL WITH DEFAULT -1 , 
		  RUN_REQUIREMENTS INTEGER , 
		  LAST_EXECUTION_AT DECIMAL(19,0) , 
		  NEXT_EXECUTION_REQUEST DECIMAL(19,0) , 
		  SCHEDULE_DELAY DECIMAL(19,0) , 
		  DELETE_AFTER_LAST_RUN INTEGER , 
		  PRIORITY INTEGER NOT NULL WITH DEFAULT 3 , 
		  SCHEDULED_BY VARCHAR(256) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_TASKSCHEDULE

ALTER TABLE NC_TASKSCHEDULE 
	ADD CONSTRAINT PN_TASKSCHEDULE PRIMARY KEY
		(PK_TASKSCHEDULE_ID);



-- DDL Statements for indexes on Table NC_TASKSCHEDULE

CREATE INDEX I1N_TASKSCHEDULE ON NC_TASKSCHEDULE 
		(FK_TASK_ID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table NC_SCHEDULED_EVENT_OVERRIDE
------------------------------------------------
 

CREATE TABLE NC_SCHEDULED_EVENT_OVERRIDE  (
		  FK_TASKSCHEDULE_ID INTEGER NOT NULL , 
		  EVENT_DATE DECIMAL(19,0) NOT NULL , 
		  EVENT_STATUS INTEGER , 
		  EVENT_PRIORITY INTEGER , 
		  FK_SCHEDULE_ID INTEGER , 
		  CANCELLED_BY VARCHAR(2000) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_SCHEDULED_EVENT_OVERRIDE

ALTER TABLE NC_SCHEDULED_EVENT_OVERRIDE 
	ADD CONSTRAINT PN_EVENT_DATES PRIMARY KEY
		(FK_TASKSCHEDULE_ID,
		 EVENT_DATE);



-- DDL Statements for indexes on Table NC_SCHEDULED_EVENT_OVERRIDE

CREATE INDEX I1N_EVENT_DATE ON NC_SCHEDULED_EVENT_OVERRIDE 
		(FK_TASKSCHEDULE_ID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table NC_TASK_ANCESTOR_STOREIDS
------------------------------------------------
 

CREATE TABLE NC_TASK_ANCESTOR_STOREIDS  (
		  TASK_ID CHAR(45) NOT NULL , 
		  ANCESTOR_STORE_ID VARCHAR(256) NOT NULL )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_TASK_ANCESTOR_STOREIDS

ALTER TABLE NC_TASK_ANCESTOR_STOREIDS 
	ADD CONSTRAINT PK_ANCESTOR_IDS PRIMARY KEY
		(TASK_ID,
		 ANCESTOR_STORE_ID);


------------------------------------------------
-- DDL Statements for table NC_TASK_HISTORY_DETAIL
------------------------------------------------
 

CREATE TABLE NC_TASK_HISTORY_DETAIL  (
		  TASK_ID CHAR(45) NOT NULL , 
		  SUB_INDEX INTEGER NOT NULL , 
		  SEVERITY INTEGER , 
		  CLASSTYPE CHAR(128) , 
		  TASK BLOB(10485760) LOGGED NOT COMPACT , 
		  STATUS INTEGER NOT NULL WITH DEFAULT 0 )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_TASK_HISTORY_DETAIL

ALTER TABLE NC_TASK_HISTORY_DETAIL 
	ADD CONSTRAINT PN_TASK_HD PRIMARY KEY
		(TASK_ID,
		 SUB_INDEX);


------------------------------------------------
-- DDL Statements for table NC_TASK_PROPERTY
------------------------------------------------
 

CREATE TABLE NC_TASK_PROPERTY  (
		  TASK_ID CHAR(45) NOT NULL , 
		  PROP_NAME CHAR(45) NOT NULL , 
		  PROP_VALUE VARCHAR(2000) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_TASK_PROPERTY

ALTER TABLE NC_TASK_PROPERTY 
	ADD CONSTRAINT PN_TASK_PROPERTY PRIMARY KEY
		(TASK_ID,
		 PROP_NAME);


------------------------------------------------
-- DDL Statements for table NC_TASK_QUEUE
------------------------------------------------
 

CREATE TABLE NC_TASK_QUEUE  (
		  TASK_ID CHAR(45) NOT NULL , 
		  SERVICE_NAME VARCHAR(40) , 
		  SERVER_GROUP VARCHAR(40) , 
		  DATE_ENTERED DECIMAL(19,0) NOT NULL , 
		  TASK BLOB(524288000) LOGGED NOT COMPACT , 
		  STATUS INTEGER NOT NULL , 
		  PRIORITY INTEGER NOT NULL , 
		  RESTART_ID CHAR(45) , 
		  SDS_INSTANCE_ID CHAR(32) , 
		  HISTORY_STORE_ID CHAR(34) , 
		  ACTUAL_EXECUTION_TIME DECIMAL(19,0) , 
		  ACTUAL_COMPLETION_TIME DECIMAL(19,0) , 
		  DISPATCHER_ID CHAR(45) , 
		  SCHEDULE_TRIGGER_NAME VARCHAR(255) , 
		  SCHEDULE_TYPE CHAR(15) , 
		  ACCOUNT_PATH VARCHAR(1024) , 
		  STOREID CHAR(34) , 
		  OBJECT_CLASS CHAR(64) , 
		  OWNER_STOREID VARCHAR(256) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_TASK_QUEUE

ALTER TABLE NC_TASK_QUEUE 
	ADD CONSTRAINT PN_TASK_QUEUE PRIMARY KEY
		(TASK_ID);



-- DDL Statements for indexes on Table NC_TASK_QUEUE

CREATE INDEX IX_NC_TSK_Q_SLTR ON NC_TASK_QUEUE 
		(STATUS ASC,
		 SERVICE_NAME ASC,
		 SERVER_GROUP ASC,
		 DATE_ENTERED ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table NC_TSE_STATE_MAP
------------------------------------------------
 

CREATE TABLE NC_TSE_STATE_MAP  (
		  TASK_ID CHAR(45) NOT NULL , 
		  STATUS INTEGER , 
		  SEQ INTEGER , 
		  STEP_COUNT INTEGER , 
		  CUR_SEQ INTEGER , 
		  COUNT_SEQ INTEGER , 
		  STOP_ON_ERROR INTEGER , 
		  RUN_VIA_MS INTEGER , 
		  STEP_FAILED INTEGER , 
		  SEQ_ON_END INTEGER , 
		  WRITE_ALL_HISTORIES INTEGER , 
		  FAIL_STATUS INTEGER , 
		  PARENT_ID CHAR(45) , 
		  EXECUTING INTEGER NOT NULL WITH DEFAULT 0 , 
		  MODCOUNT INTEGER NOT NULL WITH DEFAULT -1 )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table NC_TSE_STATE_MAP

ALTER TABLE NC_TSE_STATE_MAP 
	ADD CONSTRAINT PN_TSE_STATE_MAP PRIMARY KEY
		(TASK_ID);



-- DDL Statements for indexes on Table NC_TSE_STATE_MAP

CREATE INDEX IX_NC_TSE_STE_MAP ON NC_TSE_STATE_MAP 
		(PARENT_ID ASC,
		 SEQ ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table R_MESSAGESTRUCT_TASK
------------------------------------------------
 

CREATE TABLE R_MESSAGESTRUCT_TASK  (
		  FK_MESSAGESTRUCT_ID INTEGER NOT NULL , 
		  FK_TASK_ID INTEGER NOT NULL )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table R_MESSAGESTRUCT_TASK

ALTER TABLE R_MESSAGESTRUCT_TASK 
	ADD CONSTRAINT PR_MESSAGESTRUCT_T PRIMARY KEY
		(FK_TASK_ID,
		 FK_MESSAGESTRUCT_ID);



-- DDL Statements for indexes on Table R_MESSAGESTRUCT_TASK

CREATE INDEX I1R_MESSAGESTRUCT_ ON R_MESSAGESTRUCT_TASK 
		(FK_MESSAGESTRUCT_ID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table R_MSGSTRUCT_RECIPIENT_DELIVINF
------------------------------------------------
 

CREATE TABLE R_MSGSTRUCT_RECIPIENT_DELIVINF  (
		  FK_MESSAGESTRUCT_ID INTEGER NOT NULL , 
		  FK_DELIVERY_INFO_ID INTEGER , 
		  FK_RECIPIENT_ID INTEGER NOT NULL , 
		  ADDED_BY_RECIP_ID INTEGER , 
		  DATE_ADDED DECIMAL(18,0) )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table R_MSGSTRUCT_RECIPIENT_DELIVINF

ALTER TABLE R_MSGSTRUCT_RECIPIENT_DELIVINF 
	ADD CONSTRAINT PR_MSGSTRUCT_RECIP PRIMARY KEY
		(FK_RECIPIENT_ID,
		 FK_MESSAGESTRUCT_ID);



-- DDL Statements for indexes on Table R_MSGSTRUCT_RECIPIENT_DELIVINF

CREATE INDEX I1R_MSGSTRUCT_RECI ON R_MSGSTRUCT_RECIPIENT_DELIVINF 
		(FK_MESSAGESTRUCT_ID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table R_NEWSITEMS_NCOBJECTS
------------------------------------------------
 

CREATE TABLE R_NEWSITEMS_NCOBJECTS  (
		  NID CHAR(32) NOT NULL , 
		  FK_NCID INTEGER NOT NULL , 
		  TYPE SMALLINT )   
		 IN CTBS_4K ; 


-- DDL Statements for primary key on Table R_NEWSITEMS_NCOBJECTS

ALTER TABLE R_NEWSITEMS_NCOBJECTS 
	ADD CONSTRAINT PR_NEWSITEMS_NCOBJ PRIMARY KEY
		(NID);



-- DDL Statements for indexes on Table R_NEWSITEMS_NCOBJECTS

CREATE INDEX I1R_NEWSITEMS_NCOB ON R_NEWSITEMS_NCOBJECTS 
		(TYPE ASC)
		ALLOW REVERSE SCANS;

-- DDL Statements for indexes on Table R_NEWSITEMS_NCOBJECTS

CREATE INDEX I2R_NEWSITEMS_NCOB ON R_NEWSITEMS_NCOBJECTS 
		(FK_NCID ASC)
		ALLOW REVERSE SCANS;

-- DDL Statements for indexes on Table R_NEWSITEMS_NCOBJECTS

CREATE INDEX I3R_NEWSITEMS_NCOB ON R_NEWSITEMS_NCOBJECTS 
		(FK_NCID ASC,
		 NID ASC)
		ALLOW REVERSE SCANS;
------------------------------------------------
-- DDL Statements for table R_TASKSCHEDULE_SCHEDULE
------------------------------------------------
 

CREATE TABLE R_TASKSCHEDULE_SCHEDULE  (
		  FK_TASKSCHEDULE_ID INTEGER NOT NULL , 
		  FK_SCHEDULE_ID INTEGER NOT NULL , 
		  IS_ACTIVE INTEGER , 
		  IS_ESCALATION INTEGER )   
		 IN CTBS_4K ; 

-- DDL Statements for primary key on Table R_TASKSCHEDULE_SCHEDULE

ALTER TABLE R_TASKSCHEDULE_SCHEDULE 
	ADD CONSTRAINT PR_TASKSCHEDULE_SC PRIMARY KEY
		(FK_SCHEDULE_ID,
		 FK_TASKSCHEDULE_ID);



-- DDL Statements for indexes on Table R_TASKSCHEDULE_SCHEDULE

CREATE INDEX I1R_TASKSCHEDULE_S ON R_TASKSCHEDULE_SCHEDULE 
		(FK_TASKSCHEDULE_ID ASC)
		ALLOW REVERSE SCANS;
		
COMMIT WORK;

CONNECT RESET;

TERMINATE;

